from setuptools import setup, find_packages
import os

VERSION = '1.3'
DESCRIPTION = 'Facilitating the process to store JSON data'

with open("README.md", 'r') as r:
    long_description = r.read()

# Setting up
setup(
    name="jsondatasave",
    version=VERSION,
    author="YourAverageDev",
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'JSON', 'Data Storage'],  # Adjusted the keywords to be more representative
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    license="MIT"
)



import json


def load(FileName: str):
    """
    This function is used to load data in the JSON Format.
    """
    with open(FileName, 'r') as file:
        Save_Data = json.load(file)
    return Save_Data


def save(Data, Filename: str):
    """
    This function is used to save data in the JSON Format.
    """
    with open(Filename, "w") as dump:
        json.dump(Data, dump)
    return Data
